pub struct Control {
pub seq: u16,
pub response: Result<ControlResponse, ControlError>,
}Expand description
Control Message
This is the ‘control channel’, used for establishing and managing connections between the Arbitrator and Client(s).
Fields
seq: u16Sequence Number
This number is provided by the client. The Arbitrator will always respond with the same sequence number when replying to a specific message
response: Result<ControlResponse, ControlError>Response
The arbitrator response to the client request