pub struct Control<'a> {
pub seq: u16,
pub ty: ControlType<'a>,
}Expand description
Control Messages
These messages are used to communicate on the control layer
Fields
seq: u16Sequence Number
This number is chosen by the Client/Component, and will be echoed back by the Arbitrator when replying
ty: ControlType<'a>Control Message Type
The specific control message