pub enum ControlType<'a> {
RegisterComponent(ComponentInfo<'a>),
RegisterPubSubShortId(PubSubShort<'a>),
}Expand description
Control Message Type
The specific kind of Control Message
Variants
RegisterComponent(ComponentInfo<'a>)
Register Component
This message is used to establish/reset the connection between a given client and an Arbitrator
RegisterPubSubShortId(PubSubShort<'a>)
Register PubSubShortID
This message is used to register a path “short code”, which can use a u16 instead of a full utf-8 path to save message bandwidth